netapp_ontap.models.ems_event_message API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ems_event_message`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class EmsEventMessageSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the EmsEventMessage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the ems_event_message.

  `name GET`

    Message name of the event. Returned by default.

    Example: callhome.spares.low

  `severity GET`

    Severity of the event. Returned by default.

    Valid choices:

    - emergency
    - alert
    - error
    - notice
    - informational
    - debug